/**
 * @agentuity/local - Local development services
 *
 * Provides local storage implementations for development.
 * Runtime-specific implementations are auto-detected.
 *
 * Users can provide their own implementations via service overrides
 * by implementing these interfaces.
 */
export type { KeyValueStorage, StreamStorage, VectorStorage, QueueService, EmailService, TaskStorage, } from '@agentuity/core';
export { detectRuntime, isLocalAvailable, getRuntimeName, type Runtime } from './runtime';
export { getLocalDB, closeLocalDB, LocalKeyValueStorage, LocalStreamStorage, LocalVectorStorage, LocalQueueStorage, LocalEmailStorage, LocalTaskStorage, now, normalizeProjectPath, } from './bun';
//# sourceMappingURL=index.d.ts.map