/**
 * Runtime detection for @agentuity/local
 *
 * Detects the current JavaScript runtime and provides
 * appropriate local storage implementations.
 */
export type Runtime = 'bun' | 'node' | 'deno' | 'workers' | 'unknown';
/**
 * Detect the current runtime environment.
 */
export declare function detectRuntime(): Runtime;
/**
 * Check if local services are available for the current runtime.
 */
export declare function isLocalAvailable(): boolean;
/**
 * Get the current runtime name for logging.
 */
export declare function getRuntimeName(): string;
//# sourceMappingURL=runtime.d.ts.map