/**
 * @agentuity/local - Local development services
 *
 * Provides local storage implementations for development.
 * Runtime-specific implementations are auto-detected.
 *
 * Users can provide their own implementations via service overrides
 * by implementing these interfaces.
 */
// Runtime detection
export { detectRuntime, isLocalAvailable, getRuntimeName } from './runtime';
// Bun implementations (only available when running in Bun)
export { getLocalDB, closeLocalDB, LocalKeyValueStorage, LocalStreamStorage, LocalVectorStorage, LocalQueueStorage, LocalEmailStorage, LocalTaskStorage, now, normalizeProjectPath, } from './bun';
//# sourceMappingURL=index.js.map